<?php declare(strict_types=1);

include '../../start.php';

FeedReaderCentral\Security::verifyUser(redirectIfAnonymous: false);

page_head('Items | Documentation'); ?>
<h1>Items</h1>
<p class=back-link><?=hx_get('./', '&lang;&lang; Documentation Home')?>
<article class=docs>
    <h2>Reading an Item</h2>
    <p>Before we look at all the different ways you can produce lists of items, we will take a quick look at how the
        item page works. Within a list of items, this page can be accessed via the title of the item.
    <ul>
        <li>The title of the items is a link to the item at its original source; it will open in a new tab.
        <li>The bookmark icon shows its current bookmark status; gray is not bookmarked, green is bookmarked. Clicking
            the icon will toggle the status for the item. If the current user has any bookmarked items, a
            <strong>Bookmarked</strong> item will appear in the top menu bar.
            <em>(The application usually does not replace the menu bar; clicking the
                <strong>Feed Reader Central</strong> link will reload it.)</em>
        <li>Below the title, the source, published date, and updated date (if applicable) are displayed.
        <li>The text of the item is displayed. Images are constrained to be no wider than the screen on which they are
            being viewed, but other embedded objects (YouTube videos, etc.) with specific sizes may end up overflowing.
            <em>(Web devs, if you have any ideas on how to constrain those as well, I'm all ears&hellip;)</em>
        <li>Below the text, there are three buttons. <strong>Done</strong> leaves the item marked as having been read,
            <strong>Keep as New</strong> will mark the item as unread, and <strong>Delete</strong> will delete the item
            from the database. Any of them will return you to wherever you were when you clicked the title of the item.
    </ul>
    <h2>Viewing Items for All Feeds</h2>
    <p>There are three different ways to view items across all your subscriptions.
    <h3>Unread Items</h3>
    <p>The main page of the application (after logging on, if required) displays all currently unread items across all
        subscribed feeds. The name of the feed is a link to view just that feed&rsquo;s unread items.
    <h3>Bookmarked Items</h3>
    <p>If you have any bookmarked items, the <strong>Bookmarked</strong> link in the top menu bar will bring you to a
        list of all those items. The name of the feed is a link to view just that feed&rsquo;s bookmarked items.
    <h3>Searching for Items</h3>
    <p>The <strong>Search</strong> link in the top menu bar presents a box where search text can be entered; you can
        also choose whether to search all items, or only those that have been bookmarked. The search applies to the
        content of each item. Within the search results, there is an indicator displayed if the item is unread or
        bookmarked, and the name of the feed is not linked.
    <p>Under the hood, this uses
        <a href=https://www.sqlite.org/fts5.html#full_text_query_syntax target=_blank rel=noopener>SQLite&rsquo;s FTS5</a>,
        so it is case-insensitive by default and provides some interesting ways to query your items.
    <ul>
        <li><code>election</code> would return items with the word &ldquo;election&rdquo; in them.
        <li><code>senat*</code> would return items with words like &ldquo;Senator&rdquo;, &ldquo;senatorial&rdquo;, or
            &ldquo;Senate&rdquo; in them.
        <li><code>"election 2024"</code> <em>(note the quotes)</em> would return items that have the phrase
            &ldquo;Election 2024&rdquo; in them; <code>election 2024</code> would return items that have either
            &ldquo;election&rdquo; <em>or</em> &ldquo;2024&rdquo; in them.
        <li><code>election AND 2024</code> is the same as above; <code>AND</code> requires that both conditions be
            satisfied. (<code>OR</code> is also supported; both these must be uppercase.)
        <li><code>election NOT president*</code> would return items containing &ldquo;election&rdquo;, but only if they
            did <em>not</em> have words like &ldquo;president&rdquo; or &ldquo;presidential&rdquo;.
    </ul>
    <h2>Viewing Items by Feed</h2>
    <p>Other than the unread and bookmarked links mentioned above, lists of items by feed are linked on the
        <strong>Feeds</strong> page. Below each feed&rsquo;s title, there are links for <strong>All</strong>,
        <strong>Unread</strong>, and <strong>Bookmarked</strong>, along with a count of items that fit the status.
        (If there are no items, the word is not linked.)
    <h2>A Note on Sorting</h2>
    <p>All lists of items are sorted by date, with the most recent items on top. Both the RSS and Atom specifications
        provide both a published date and an updated date. When selecting a date for sorting, the application uses the
        updated date if it is present; otherwise, it uses the published date. Some sites update their items more than
        others; if the items seem to move around in the list after a refresh, this is likely the cause.
</article><?php
page_foot();
