<?php declare(strict_types=1);

use BitBadger\PDODocument\{DocumentException, Find};
use FeedReaderCentral\{Feed, Table, User};

require __DIR__ . '/../cli-start.php';

cli_title('FEED REFRESH');

if ($argc < 2) display_help();

switch ($argv[1]) {
    case 'all':
        refresh_all();
        break;
    default:
        printfn('Unrecognized option "%s"', $argv[1]);
        display_help();
}


/**
 * Display the options for this utility and exit
 */
function display_help(): never
{
    printfn('Options:');
    printfn(' - all');
    printfn('     Refreshes all feeds');
    exit(0);
}

function refresh_all(): void
{
    try {
        $users = [];
        foreach (Feed::retrieveAll()->items() as /** @var Feed $feed */ $feed) {
            $result  = Feed::refreshFeed($feed->id, $feed->url);
            $userKey = "$feed->user_id";
            if (!key_exists($userKey, $users)) $users[$userKey] = Find::byId(Table::USER, $feed->user_id, User::class);
            if (array_key_exists('error', $result)) {
                printfn('ERR (%s) %s', $users[$userKey]->email, $feed->url);
                printfn('         %s', $result['error']);
            } else {
                printfn('OK  (%s) %s', $users[$userKey]->email, $feed->url);
            }
        }
        printfn(PHP_EOL . 'All feeds refreshed');
    } catch (DocumentException $ex) {
        printfn("ERR $ex");
        return;
    }
}
